@@ -1,9 +1,22 @@
 from dependency_injector import containers, providers
 
+from novelsave.containers import Application
+from novelsave.services.cloud.filehost import AnonFilesHost, GoFilesHost, NoneFilesHost
 from .endpoints import DownloadHandler, SearchHandler
 from .session import SessionHandler, Session
 
 
+class CloudContainer(containers.DeclarativeContainer):
+    config = providers.Configuration(strict=True)
+
+    filehost = providers.Selector(
+        config.cloud.filehost,
+        anonfiles=providers.Factory(AnonFilesHost),
+        gofiles=providers.Factory(GoFilesHost),
+        none=providers.Factory(NoneFilesHost),
+    )
+
+
 class SessionContainer(containers.DeclarativeContainer):
     config = providers.Configuration(strict=True)
 
@@ -27,9 +40,19 @@ class SessionContainer(containers.DeclarativeContainer):
 
 
 class DiscordApplication(containers.DeclarativeContainer):
-    discord_config = providers.Configuration(strict=True)
+    config = providers.Configuration(strict=True)
+
+    application = providers.Container(
+        Application,
+        config=config.app,
+    )
 
     session = providers.Container(
         SessionContainer,
-        config=discord_config,
+        config=config.discord,
+    )
+
+    cloud = providers.Container(
+        CloudContainer,
+        config=config.discord,
     )
