@@ -1,16 +1,20 @@
 from abc import ABC, abstractmethod
-from typing import List, Tuple
+from typing import List
 
 from novelsave.core import dtos
 
 
 class BaseSourceGateway(ABC):
-
     @property
     @abstractmethod
     def name(self) -> str:
         """name of the corresponding source"""
 
+    @property
+    @abstractmethod
+    def base_url(self) -> str:
+        """Base url or network location of the source"""
+
     @property
     @abstractmethod
     def is_search_capable(self) -> bool:
